﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Microsoft.Phone.Controls;
using Microsoft.Devices.Sensors;
using System.IO.IsolatedStorage;
using System.IO;
using System.Diagnostics;

namespace PhoneAppSensorsLogging
{
    /// <summary>
    /// Application illustrates how to use the accelerometer sensor.
    /// Remeber to add the Microsoft.Devices.Sensors.dll file to the list of References
    /// (right click and select "Add Reference...").
    /// </summary>
    public partial class MainPage : PhoneApplicationPage
    {

        // Access to the accelerometer sensor
        private Accelerometer accelerometer;

        // Storing the current accelerometer values
        private double[] lastAccelerometerReading = new double[]{0,0,0};

        // Initialize the isolated storage to save and read files
        IsolatedStorageFile storage = IsolatedStorageFile.GetUserStoreForApplication();

        // Filename where we store accelerometer values
        private string fileName = "accelerometer.txt";



        // Constructor
        public MainPage()
        {
            InitializeComponent();

            // Disable the frame rate counter (tiny numbers on the right side of the screen)
            Application.Current.Host.Settings.EnableFrameRateCounter = false;

            
            // Initialize storage to save accelerometer values
            if (!this.storage.FileExists(this.fileName))
            {
                this.storage.CreateFile(this.fileName).Flush();
            }
           

            // Initialize accelerometer
            this.accelerometer = new Accelerometer();

            // Subscribe for all events that occur when the accelerometer
            // values change (-> movement of the device)
            this.accelerometer.ReadingChanged += new EventHandler<AccelerometerReadingEventArgs>(accelerometer_ReadingChanged);

            // Start the accelerometer sensor
            this.accelerometer.Start();
        }



        // Handler method for update events from the accelerometer
        void accelerometer_ReadingChanged(object sender, AccelerometerReadingEventArgs e)
        {
            // Store the current accelerometer values
            this.lastAccelerometerReading[0] = e.X;
            this.lastAccelerometerReading[1] = e.Y;
            this.lastAccelerometerReading[2] = e.Z;

            Deployment.Current.Dispatcher.BeginInvoke(() =>
            {
                // Show the current accelerometer values on screen
                this.textBlockAccelerometer.Text =
                    "X:  " + e.X.ToString("0.0") + Environment.NewLine +
                    "Y:  " + e.Y.ToString("0.0") + Environment.NewLine +
                    "Z:  " + e.Z.ToString("0.0");
            });
        }




        // Save the current data to the storage file
        private void buttonSave_Click(object sender, RoutedEventArgs e)
        {
            // Check that file exists
            if (this.storage.FileExists(this.fileName))
            {
                try
                {
                    // Open the file for write access
                    using (StreamWriter writer =
                        new StreamWriter(this.storage.OpenFile(this.fileName,
                            FileMode.Append, FileAccess.Write)))
                    {
                        // Add a line to the file
                        writer.WriteLine("X: " + this.lastAccelerometerReading[0].ToString("0.0") +
                            ", Y: " + this.lastAccelerometerReading[1].ToString("0.0") +
                            ", Z: " + this.lastAccelerometerReading[2].ToString("0.0"));
                        writer.Flush();
                        writer.Close();
                    }
                }
                catch (IsolatedStorageException ex)
                {
                    // Catch the exception in case anything goes wrong
                    Debug.WriteLine(ex.StackTrace);
                }
            }
        }




        // Read the saved data
        private void buttonRead_Click(object sender, RoutedEventArgs e)
        {
            // Erase the entries in the listbox
            this.listBoxSensorValues.Items.Clear();

            // First we check that the file exists
            if (this.storage.FileExists(this.fileName))
            {
                try
                {
                    // Open the text file with the StreamReader 
                    using (StreamReader reader =
                        new StreamReader(this.storage.OpenFile(this.fileName,
                            FileMode.Open, FileAccess.Read)))
                    {
                        while (!reader.EndOfStream)
                        {
                            // Read the content of the file
                            this.listBoxSensorValues.Items.Add(reader.ReadLine());
                        }
                        reader.Close();
                    }
                }
                catch (IsolatedStorageException ex)
                {
                    // Catch the exception in case anything goes wrong
                    Debug.WriteLine(ex.StackTrace);
                }
            }
        }
    }
}